@@ -23,7 +23,7 @@ import requests
 from requests.exceptions import ConnectionError
 
 from mona_sdk.client_exceptions import (
-    MonaConfigUploadException,
+    MonaConfigException,
     MonaInitializationException,
 )
 from .client_util import get_boolean_value_for_env_var
@@ -434,35 +434,37 @@ class Client:
         """
         :return: A json-serializable dict with the current defined configuration.
         """
+        app_server_response = self._app_server_request("configs")
         try:
-            config_response = requests.post(
-                f"{self._app_server_url}/configs",
-                headers=get_basic_auth_header(
-                    self.api_key, self.should_use_authentication
-                ),
-                data="{}",
-            )
-            config_data = config_response.json()
-            if not config_response.ok:
-                return self._handle_config_error(GET_CONFIG_ERROR_MESSAGE)
-
-        except ConnectionError:
-            return self._handle_config_error(APP_SERVER_CONNECTION_ERROR_MESSAGE)
-        except JSONDecodeError:
+            return {
+                self._user_id: app_server_response["response_data"][
+                    "raw_configuration_data"
+                ]
+            }
+        except KeyError:
             return self._handle_config_error(GET_CONFIG_ERROR_MESSAGE)
 
-        return {self._user_id: config_data["response_data"]["raw_configuration_data"]}
+    @Decorators.refresh_token_if_needed
+    def get_suggested_config(self):
+        """
+        :return: A json-serializable dict with a suggested configuration.
+        """
+        app_server_response = self._app_server_request("get_new_config_fields")
+        try:
+            return app_server_response["response_data"]["suggested_config"]
+        except KeyError:
+            return self._handle_config_error(GET_CONFIG_ERROR_MESSAGE)
 
     def _handle_config_error(self, error_message):
         """
-        Logs an error and raises MonaExportException if RAISE_EXPORT_EXCEPTIONS is true,
+        Logs an error and raises MonaConfigException if RAISE_CONFIG_EXCEPTIONS is true,
         else returns false.
         """
         error_message += self._get_unauthenticated_mode_error_message()
 
         self._logger.error(error_message)
         if self.raise_config_exceptions:
-            raise MonaConfigUploadException(error_message)
+            raise MonaConfigException(error_message)
         return False
 
     def _get_unauthenticated_mode_error_message(self):
@@ -476,3 +478,26 @@ class Client:
             if self.should_use_authentication
             else UNAUTHENTICATED_ERROR_CHECK_MESSAGE
         )
+
+    def _app_server_request(self, endpoint_name, data="{}"):
+        """
+        Send a request to Mona's app-server.
+        """
+        try:
+            config_response = requests.post(
+                f"{self._app_server_url}/{endpoint_name}",
+                headers=get_basic_auth_header(
+                    self.api_key, self.should_use_authentication
+                ),
+                data=data,
+            )
+            json_response = config_response.json()
+            if not config_response.ok:
+                return self._handle_config_error(GET_CONFIG_ERROR_MESSAGE)
+
+            return json_response
+
+        except ConnectionError:
+            return self._handle_config_error(APP_SERVER_CONNECTION_ERROR_MESSAGE)
+        except JSONDecodeError:
+            return self._handle_config_error(GET_CONFIG_ERROR_MESSAGE)
